BuildRunnerTracker class final

Constructors

BuildRunnerTracker(TempDirectory _temp)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupAll() Future<void>
cleanupPackage(String path, {bool isPackageDir = false}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageDir(String rootPath) String
recordBuildRunnerPid(String rootPath, int pid) Future<void>
registerOwner(String rootPath) Future<void>
removeOwner(String rootPath) Future<void>
startDetachedCleanup() Future<void>
startDetachedWatchdog() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited