ProcessContext class final

Constructors

ProcessContext(ContextRoot contextRoot, {required String packageDirectory, required ProcessLogger log, required ProcessStarted onStarted, List<String> buildFilters = const []})

Properties

buildFilters List<String>
final
contextRoot → ContextRoot
final
hashCode int
The hash code for this object.
no setterinherited
isRunning bool
no setter
pid int?
no setter
rootPath String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited